/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/

#include "dcted.h"
#include "dctcreat.h"

#include <Unidraw/catalog.h>
#include <Unidraw/unidraw.h>
#include <Unidraw/globals.h>
#include <Unidraw/Graphic/graphic.h>
#include <InterViews/world.h>

#include "epicsVersion.h"

static char* font12_helv = "*-helvetica-medium-r-*-80-75-* Helvetica 8";

static PropertyData properties[] = {
    { "*title",        "GDCT v1.2beta1 - " EPICS_VERSION_STRING },
    { "*domain",        "drawing" },
    { "*singleClick",   "false" },
    { "*dialogSize",   ".75" },
    { "*menu_sb*singleClick",   "true" },
    { "*syncScroll",   "false" },
    { "*history",	"20" },
	{ "*font1",     "*-courier-medium-r-*-80-*    Courier 8" },
    { "*font2",     "*-courier-medium-r-*-100-*   Courier 10" },
    { "*font3",     "*-courier-bold-r-*-120-*     Courier-Bold 12" },
    { "*font4",     "*-helvetica-medium-r-*-120-* Helvetica 12" },
    { "*font5",     "*-helvetica-medium-r-*-140-* Helvetica 14" },
    { "*font6",     "*-helvetica-bold-r-*-140-*   Helvetica-Bold 14" },
    { "*font7",     "*-helvetica-medium-o-*-140-* Helvetica-Oblique 14" },
    { "*font8",     "*-times-medium-r-*-120-*     Times-Roman 12" },
    { "*font9",     "*-times-medium-r-*-140-*     Times-Roman 14" },
    { "*font10",    "*-times-bold-r-*-140-*       Times-Bold 14" },
    { "*font11",    "*-times-medium-i-*-140-*     Times-Italic 14" },
#if 0
 #ifdef GDCT_STYLE
    { "*font12",    "*-helvetica-medium-r-*-80-* Helvetica 8" },
 #else
    { "*font12",    "*-helvetica-medium-r-*-80-75-* Helvetica 8" },
 #endif
    { "*font12",    font12_helv },
#endif
    { "*font12",    "*-helvetica-medium-r-*-80-75-* Helvetica 8" },
    { "*font13",    "*-helvetica-medium-r-*-100-* Helvetica 10" },
    { "*fgcolor1",  "Black" },
    { "*fgcolor2",  "Brown 42240 10752 10752" },
    { "*fgcolor3",  "Red" },
    { "*fgcolor4",  "Orange" },
    { "*fgcolor5",  "Yellow" },
    { "*fgcolor6",  "Green" },
    { "*fgcolor7",  "Blue" },
    { "*fgcolor8",  "Indigo 48896 0 65280" },
    { "*fgcolor9",  "Violet 20224 12032 20224" },
    { "*fgcolor10", "White" },
    { "*fgcolor11", "LtGray 50000 50000 50000" },
    { "*fgcolor12", "DkGray 33000 33000 33000" },
    { "*bgcolor1",  "Black" },
    { "*bgcolor2",  "Brown 42240 10752 10752" },
    { "*bgcolor3",  "Red" },
    { "*bgcolor4",  "Orange" },
    { "*bgcolor5",  "Yellow" },
    { "*bgcolor6",  "Green" },
    { "*bgcolor7",  "Blue" },
    { "*bgcolor8",  "Indigo 48896 0 65280" },
    { "*bgcolor9",  "Violet 20224 12032 20224" },
    { "*bgcolor10", "White" },
    { "*bgcolor11", "LtGray 50000 50000 50000" },
    { "*bgcolor12", "DkGray 33000 33000 33000" },
    { nil }
};

static OptionDesc options[] = {
    { nil }
};

int use_gdct_style_stuff = 0;

int main (int argc, char** argv)
{
    dct_creator creator;

#ifdef ALLOW_FREE_GDCT_SIZES
	if(strstr(argv[0],"free_gdct"))
	{
		use_gdct_style_stuff=0;
		printf("using free_gdct style windows and fonts\n");
	}
	else
#endif
		use_gdct_style_stuff=1;

	if(use_gdct_style_stuff)
		strcpy(font12_helv,"*-helvetica-medium-r-*-80-* Helvetica 8");

    DctUnidraw* unidraw = new DctUnidraw(
        new DctCatalog("dct", &creator, DCT_VERSION),
						argc, argv, options, properties);

	ToolPalette* tp = new ToolPalette;
    unidraw->Open(new Dct(tp));
	unidraw->Open(tp);
    unidraw->Run();

    delete unidraw;
    return 0;
}
